==> haskell-http-api-data-0.4.1.1-18-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-http-api-data.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 http-api-data
version:              0.4.1.1
visibility:           public
id:                   http-api-data-0.4.1.1-HGW0HgZdLakLS3qzyoV6Ne
key:                  http-api-data-0.4.1.1-HGW0HgZdLakLS3qzyoV6Ne
license:              BSD-3-Clause
maintainer:           Nickolay Kudasov <nickolay.kudasov@gmail.com>
author:               Nickolay Kudasov <nickolay.kudasov@gmail.com>
stability:            unstable
homepage:             http://github.com/fizruk/http-api-data
synopsis:
    Converting to/from HTTP API data like URL pieces, headers and query parameters.

description:
    This package defines typeclasses used for converting Haskell data types to and from HTTP API data.

    Please see README.md

category:             Web
abi:                  b3a510987d9a6722623d1e5dc262869e
exposed:              True
exposed-modules:
    Web.FormUrlEncoded Web.HttpApiData Web.Internal.FormUrlEncoded
    Web.Internal.HttpApiData

import-dirs:          /usr/lib/ghc-8.8.2/site-local/http-api-data-0.4.1.1
library-dirs:         /usr/lib/ghc-8.8.2/site-local/http-api-data-0.4.1.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.8.2/http-api-data-0.4.1.1
hs-libraries:         HShttp-api-data-0.4.1.1-HGW0HgZdLakLS3qzyoV6Ne
depends:
    attoparsec-0.13.2.3-EeyhxyuKI5DE0uzyJdcxCo
    attoparsec-iso8601-1.0.1.0-LEsRFhiyQW6n8GgYoSRz3 base-4.13.0.0
    base-compat-0.11.1-4oueEGUxmwHC6tuHqQ6hE2 bytestring-0.10.10.0
    containers-0.6.2.1 cookie-0.4.5-7vzD1BW7e5L2KNeTKf8wPs
    hashable-1.2.7.0-BxGxAJSPpuh3YKsULesjmE
    http-types-0.12.3-CTw55UHXldfH5I7I552Qqq
    tagged-0.8.6-LfhHZ57rMjK9JkdnSRh9cF text-1.2.4.0
    time-compat-1.9.2.2-KV8Bub27V9nLikJVfESPY
    unordered-containers-0.2.10.0-7SjMUGSLAdi81baGHdq4uZ
    uuid-types-1.0.3-7nXo0gNPXxPANvYOUwiH1f

haddock-interfaces:
    /usr/share/doc/haskell-http-api-data/html/http-api-data.haddock

haddock-html:         /usr/share/doc/haskell-http-api-data/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-http-api-data-0.4.1.1-22-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-http-api-data.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 http-api-data
version:              0.4.1.1
visibility:           public
id:                   http-api-data-0.4.1.1-A6Kx1tnT4vO5Jcau90rdqU
key:                  http-api-data-0.4.1.1-A6Kx1tnT4vO5Jcau90rdqU
license:              BSD-3-Clause
maintainer:           Nickolay Kudasov <nickolay.kudasov@gmail.com>
author:               Nickolay Kudasov <nickolay.kudasov@gmail.com>
stability:            unstable
homepage:             http://github.com/fizruk/http-api-data
synopsis:
    Converting to/from HTTP API data like URL pieces, headers and query parameters.

description:
    This package defines typeclasses used for converting Haskell data types to and from HTTP API data.

    Please see README.md

category:             Web
abi:                  a2537f3d941a533ab4f9ea95b88564a3
exposed:              True
exposed-modules:
    Web.FormUrlEncoded Web.HttpApiData Web.Internal.FormUrlEncoded
    Web.Internal.HttpApiData

import-dirs:          /usr/lib/ghc-8.8.3/site-local/http-api-data-0.4.1.1
library-dirs:         /usr/lib/ghc-8.8.3/site-local/http-api-data-0.4.1.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.8.3/http-api-data-0.4.1.1
hs-libraries:         HShttp-api-data-0.4.1.1-A6Kx1tnT4vO5Jcau90rdqU
depends:
    attoparsec-0.13.2.3-6p25usB4Z80LvzCYs9NN4A
    attoparsec-iso8601-1.0.1.0-ChHcDGJ28hDCx4msU8a2Oi base-4.13.0.0
    base-compat-0.11.1-4oueEGUxmwHC6tuHqQ6hE2 bytestring-0.10.10.0
    containers-0.6.2.1 cookie-0.4.5-7vzD1BW7e5L2KNeTKf8wPs
    hashable-1.2.7.0-BxGxAJSPpuh3YKsULesjmE
    http-types-0.12.3-GTfEY2QwltiKeg5SrqBav2
    tagged-0.8.6-LfhHZ57rMjK9JkdnSRh9cF text-1.2.4.0
    time-compat-1.9.3-HUOiaCe6hayJTG7vmGayqN
    unordered-containers-0.2.10.0-1E0nFKYS8XWLVv5PGwMT0V
    uuid-types-1.0.3-7nXo0gNPXxPANvYOUwiH1f

haddock-interfaces:
    /usr/share/doc/haskell-http-api-data/html/http-api-data.haddock

haddock-html:         /usr/share/doc/haskell-http-api-data/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
